/*!
 * Script for initializing frontend functions and libs.
 *
 * @since 1.0.0
 */
/* global jQuery */
( function($) {
	'use strict';

	var Carbon = {
		cache: {},

		init: function() {
			this.cacheElements();
			this.bindEvents();
		},

		cacheElements: function() {
			this.cache.$window     = $(window);
			this.cache.$document   = $(document);
			this.cache.$body       = $('body');
			this.cache.$menuToggle = $('#menu-toggle');
			this.cache.$MenuBar    = $('#site-navigation');
		},

		bindEvents: function(){
			var self = this;

			// Menu button toggles menu Bar
			self.cache.$menuToggle.on('click', function(e) {
				e.preventDefault();
				e.stopPropagation();
				self.toggleMenuBar();
			});

			self.cache.$document.on('ready', function() {
				self.skipLinkFocusFix();

				self.resizeArticle();
			});

			$(window).on('resize', function(){
				self.resizeArticle();
			});
		},

		resizeArticle: function() {
			var $body = this.cache.$body;
			if ( ! $body.hasClass('nav-stripped') || $body.hasClass('page') ) {
				return;
			}

			var vph = $(window).height() - $('.site-header').height();
			$('.article-cover').css({'height': vph + 'px'});
		},

		toggleMenuBar: function() {
			var $body = this.cache.$body,
				$menuBar =	this.cache.$MenuBar,
				$menuToggle = this.cache.$menuToggle;

			$menuToggle.find('.genericon').toggleClass('genericon-menu genericon-close-alt');

			if ( $menuBar.hasClass('toggled-on') ) {
				$body.removeClass('pushed');
				$menuBar.removeClass('toggled-on');
			} else {
				$body.addClass('pushed');
				$menuBar.addClass('toggled-on');
			}
		},

		skipLinkFocusFix: function(){
			var is_webkit = navigator.userAgent.toLowerCase().indexOf( 'webkit' ) > -1,
			    is_opera  = navigator.userAgent.toLowerCase().indexOf( 'opera' )  > -1,
			    is_ie     = navigator.userAgent.toLowerCase().indexOf( 'msie' )   > -1;

			if ( ( is_webkit || is_opera || is_ie ) && document.getElementById && window.addEventListener ) {
				window.addEventListener( 'hashchange', function() {
					var element = document.getElementById( location.hash.substring( 1 ) );

					if ( element ) {
						if ( ! /^(?:a|select|input|button|textarea)$/i.test( element.tagName ) ) {
							element.tabIndex = -1;
						}

						element.focus();
					}
				}, false );
			}
		}

	};

	Carbon.init();
} )( jQuery );
