<?php
/**
 * The header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="content">
 *
 * @package Carbon
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="profile" href="http://gmpg.org/xfn/11">
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">

<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'carbon' ); ?></a>

<header id="masthead" class="site-header" role="banner">
	<div class="site-header__inner">
		<div class="site-branding">
			<?php if ( stag_get_logo()->has_logo() ) : ?>
				<div class="custom-logo">
					<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"></a>
				</div>
			<?php else : ?>
				<h1 class="site-title">
					<?php // Site title
					if ( get_bloginfo( 'name' ) ) : ?>
						<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
							<?php bloginfo( 'name' ); ?>
						</a>
					<?php endif; ?>

					<?php $description = get_bloginfo( 'description', 'display' );
					if ( $description || is_customize_preview() ) : ?>
						<br>
						<p class="site-description"><?php echo esc_html( get_bloginfo( 'description', 'display' ) ); ?></p>
					<?php endif; ?>
				</h1>

			<?php endif; ?>

			<?php if ( has_nav_menu( 'primary' ) ) : ?>
				<nav id="site-navigation" class="navigation main-navigation" role="navigation">
					<?php
					wp_nav_menu( array(
						'theme_location' => 'primary',
						'menu_class'     => 'primary-menu',
						'container'      => false,
						'fallback_cb'    => false,
					) ); ?>
				</nav><!-- #site-navigation -->

				<button id="menu-toggle" class="menu-toggle">
					<span class="genericon genericon-menu"></span>
				</button>
			<?php endif; ?>

			<?php $nav_layout = stag_theme_mod( 'theme_options', 'nav-layout' ); ?>
			<?php if ( 'stripped' == $nav_layout && function_exists( 'jetpack_social_menu' ) ) :
				jetpack_social_menu();
			endif; ?>

		</div>
	</div>
</header><!-- #masthead -->

<?php // Show header image on homepage
if ( is_home() ) :
	get_template_part( 'partials/custom', 'header' );
endif;
?>

<div id="page" class="hfeed site">

	<div id="content" class="site-content">
