<?php
/**
 * Carbon Theme Customizer
 *
 * @package Stag_Customizer
 * @subpackage Carbon
 */

function stag_customize_register_sections( $wp_customize ) {

	// Priority for first section
	$priority = new Stag_Prioritizer( 0, 10 );

	$wp_customize->get_section( 'background_image' )->priority = $priority->add();
	$wp_customize->get_control( 'header_textcolor' )->priority = 20;

	// Rename Background Image section to Background
	$wp_customize->get_section( 'background_image' )->title = esc_html__( 'Background', 'carbon' );

	$wp_customize->get_section( 'title_tagline' )->priority = $priority->add();

	$wp_customize->add_section( 'fonts', array(
		'title'       => _x( 'Fonts', 'Theme customizer section title', 'carbon' ),
		'priority'    => $priority->add(),
		'description' => sprintf(
					esc_html__( 'The list of Google fonts is long! You can %s before making your choices.', 'carbon' ),
					sprintf(
						'<a href="%1$s" target="_blank">%2$s</a>',
						esc_url( 'https://www.google.com/fonts' ),
						esc_html__( 'preview', 'carbon' )
					)
				)
	) );

	$wp_customize->add_section( 'portfolio', array(
		'title'    => _x( 'Portfolio', 'Theme customizer section title', 'carbon' ),
		'priority' => $priority->add()
	) );

	$wp_customize->add_section( 'theme_options', array(
		'title'    => _x( 'Theme Options', 'Theme customizer section title', 'carbon' ),
		'priority' => $priority->add()
	) );

	$wp_customize->add_section( 'error_page', array(
		'title'    => _x( '404 Error Page', 'Theme customizer section title', 'carbon' ),
		'priority' => $priority->add()
	) );

	// Add an additional description to the header image section.
	$wp_customize->get_section( 'header_image' )->description = esc_html__( 'Applied to the top of page for homepage.', 'carbon' );
	$wp_customize->get_control( 'header_image' )->priority = 200;

	$wp_customize->add_section( 'footer', array(
		'title'    => _x( 'Footer', 'Theme customizer section title', 'carbon' ),
		'priority' => $priority->add()
	) );

	// Remove Jetpack's Testimonial customizer options
	$wp_customize->remove_section( 'jetpack_testimonials' );
}

add_action( 'customize_register', 'stag_customize_register_sections', 100 );

if ( ! function_exists( 'carbon_customizer_scripts' ) ) :
/**
 * Enqueue customizer sections script
 *
 * @since  1.0.0.
 *
 * @return void
 */
function carbon_customizer_scripts() {
	// Styles
	wp_enqueue_style(
		'stag-customizer-chosen',
		get_template_directory_uri() . '/stag-customizer/css/chosen/chosen.css',
		array(),
		'1.4.2'
	);

	// Scripts
	wp_enqueue_script(
		'stag-customizer-chosen',
		get_template_directory_uri() . '/stag-customizer/js/chosen.jquery.js',
		array( 'jquery', 'customize-controls' ),
		'1.4.2',
		true
	);

	wp_enqueue_script(
		'stag-customizer-sections',
		get_template_directory_uri() . '/stag-customizer/js/customizer-sections.js',
		array( 'customize-controls', 'stag-customizer-chosen' ),
		CARBON_VERSION,
		true
	);
	$localize = array(
		'fontOptions'               => stag_get_font_property_option_keys(),
		'chosen_no_results_default' => esc_html__( 'No results match', 'carbon' ),
		'chosen_no_results_fonts'   => esc_html__( 'No matching fonts', 'carbon' ),
	);
	// Localize the script
	wp_localize_script(
		'stag-customizer-sections',
		'stagCustomizerL10n',
		$localize
	);

}
endif;

add_action( 'customize_controls_enqueue_scripts', 'carbon_customizer_scripts' );

/**
 * Default theme customizations.
 *
 * @return $options an array of default theme options
 */
function stag_get_theme_mods( $args = array() ) {

	$defaults = array(
		'keys_only' => false,
	);

	$args = wp_parse_args( $args, $defaults );

	// Priority for first section
	$priority = new Stag_Prioritizer( 0, 10 );

	// Holds all customizer sections and settings
	$mods = array();

	$google_fonts = stag_all_font_choices();

	$priority->inc( 20 );

	$mods['colors'] = array(
		'accent' => array(
			'title'             => esc_html__( 'Accent Color', 'carbon' ),
			'type'              => 'WP_Customize_Color_Control',
			'default'           => '#a0d8d1',
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'sanitize_hex_color',
		),
		'overlay-nav-color' => array(
			'title'             => esc_html__( 'Menu Links Color', 'carbon' ),
			'type'              => 'WP_Customize_Color_Control',
			'default'           => '#000',
			'transport'         => 'postMessage',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'sanitize_hex_color',
		),
		'overlay-nav-hover-color' => array(
			'title'             => esc_html__( 'Menu Links Hover Color', 'carbon' ),
			'type'              => 'WP_Customize_Color_Control',
			'default'           => '#a0d8d1',
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'sanitize_hex_color',
		),
	);

	$priority->reboot();
	$priority->inc( 40 );

	$mods['title_tagline'] = array(
		'logo-regular' => array(
			'title'             => esc_html__( 'Regular Logo', 'make' ),
			'type'              => 'Carbon_Customize_Image_Control',
			'transport'         => 'postMessage',
			'default' => '',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'esc_url_raw',
		),
		'logo-retina' => array(
			'title'             => esc_html__( 'Retina Logo (2x)', 'make' ),
			'description'       => esc_html__( 'The Retina Logo should be twice the size of the Regular Logo.', 'make' ),
			'type'              => 'Carbon_Customize_Image_Control',
			'transport'         => 'postMessage',
			'default' => '',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'esc_url_raw',
		),
	);

	$priority->reboot();

	$mods['fonts'] = array(
		'font-header' => array(
			'title'             => esc_html__( 'Headers', 'carbon' ),
			'type'              => 'select',
			'default'           => 'Montserrat',
			'transport'         => 'refresh',
			'choices'           => $google_fonts,
			'priority'          => $priority->add(),
			'sanitize_callback' => 'sanitize_text_field',
		),
		'font-body' => array(
			'title'             => esc_html__( 'Body', 'carbon' ),
			'type'              => 'select',
			'default'           => 'Muli',
			'transport'         => 'refresh',
			'choices'           => $google_fonts,
			'priority'          => $priority->add(),
			'sanitize_callback' => 'sanitize_text_field',
		),
		'subset-line' => array(
			'type'              => 'Stag_Customize_Misc_Control',
			'default'           => false,
			'option'            => 'line',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'sanitize_text_field',
		),
		'subset' => array(
			'title'             => esc_html__( 'Character Subset', 'carbon' ),
			'type'              => 'select',
			'default'           => 'latin',
			'choices'           => stag_get_google_font_subsets(),
			'priority'          => $priority->add(),
			'sanitize_callback' => 'sanitize_text_field',
		),
		'subset-info' => array(
			'type'        => 'Stag_Customize_Misc_Control',
			'default'     => false,
			'description' => sprintf(
						esc_html__( 'Not all fonts provide each of these subsets. Please visit the %s to see which subsets are available for each font.', 'carbon' ),
						sprintf(
							'<a href="%1$s" target="_blank">%2$s</a>',
							esc_url( 'https://www.google.com/fonts' ),
							esc_html__( 'Google Fonts website', 'carbon' )
						)
					),
			'priority'    => $priority->add(),
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$priority->reboot();

	$mods['theme_options'] = array(
		'layout' => array(
			'title'             => esc_html__( 'Posts Layout', 'carbon' ),
			'type'              => 'Carbon_Customizer_Layout_Control',
			'default'           => '1-2-1-2',
			'choices'           => array(
				'2-1-2-1' => '2-1-2-1',
				'2-2-2-2' => '2-2-2-2',
				'1-2-1-2' => '1-2-1-2',
				'1-1-1-1' => '1-1-1-1',
			),
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'sanitize_text_field',
		),
		'post-titles-visibility' => array(
			'title'             => esc_html__( 'Posts Grid Titles Visibility', 'carbon' ),
			'type'              => 'radio',
			'default'           => 'hidden',
			'choices'           => array(
				'hidden'  => esc_html__( 'Visible on hover', 'carbon' ),
				'visible' => esc_html__( 'Hidden on hover', 'carbon' ),
			),
			'priority'          => $priority->add(),
			'transport'         => 'refresh',
			'sanitize_callback' => 'stag_sanitize_radio',
		),
		'nav-layout' => array(
			'title'             => esc_html__( 'Navigation Layout', 'carbon' ),
			'type'              => 'radio',
			'default'           => 'stripped',
			'choices'           => array(
				'stripped' => esc_html__( 'Stripped', 'carbon' ),
				'overlay'  => esc_html__( 'Overlay', 'carbon' ),
			),
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'sanitize_text_field',
		),
		'sticky-post-label' => array(
			'title'             => esc_html__( 'Sticky Post Label', 'carbon' ),
			'type'              => 'text',
			'default'           => esc_html__( 'Featured', 'carbon' ),
			'transport'         => 'postMessage',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'sanitize_text_field',
		),
		'subset-line' => array(
			'type'              => 'Stag_Customize_Misc_Control',
			'default'           => false,
			'option'            => 'line',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'sanitize_text_field',
		),
		'other-options-heading' => array(
			'type'              => 'Stag_Customize_Misc_Control',
			'default'           => false,
			'description'       => esc_html__( 'Other Options', 'carbon' ),
			'option'            => 'heading',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'sanitize_text_field',
		),
		'show-avatar' => array(
			'title'             => esc_html__( 'Show author avatar in Post Meta', 'carbon' ),
			'type'              => 'checkbox',
			'default'           => true,
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'absint',
		),
		'show-reading-time' => array(
			'title'             => esc_html__( 'Show Post Reading Time in Post Meta', 'carbon' ),
			'type'              => 'checkbox',
			'default'           => true,
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'absint',
		),
		'sidebar-heading' => array(
			'type'              => 'Stag_Customize_Misc_Control',
			'default'           => false,
			'description'       => esc_html__( 'Hide Sidebar', 'carbon' ),
			'option'            => 'heading',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'sanitize_text_field',
		),
		'hide-sidebar' => array(
			'title'             => esc_html__( 'Sitewide', 'carbon' ),
			'type'              => 'checkbox',
			'default'           => false,
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'absint',
		),
		'hide-sidebar-on-posts' => array(
			'title'             => esc_html__( 'Only on Posts &amp; Pages', 'carbon' ),
			'type'              => 'checkbox',
			'default'           => false,
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'absint',
		),
	);

	$priority->reboot();

	$mods['error_page'] = array(
		'error-title' => array(
			'title'             => esc_html__( 'Title', 'carbon' ),
			'type'              => 'text',
			'default'           => esc_html__( 'Nothing found.', 'carbon' ),
			'transport'         => 'postMessage',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'sanitize_text_field',
		),
		'error-description' => array(
			'title'             => esc_html__( 'Description', 'carbon' ),
			'type'              => 'textarea',
			'description'       => esc_html__( 'HTML and shortcodes are allowed.', 'carbon' ),
			'default'           => esc_html__( 'Nothing to see here.', 'carbon' ),
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'sanitize_text_field',
		),
		'error-page-background' => array(
			'title'             => esc_html__( 'Page Background', 'carbon' ),
			'type'              => 'Stag_Customize_Image_Control',
			'default'           => '',
			'transport'         => 'postMessage',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'esc_url_raw',
		),
	);

	$priority->reboot();

	$mods['header_image'] = array(
		'header-image-text' => array(
			'title'             => esc_html__( 'Header Image Text', 'carbon' ),
			'type'              => 'textarea',
			'description'       => esc_html__( 'H1-H6, strong, em tags and shortcodes are allowed.', 'carbon' ),
			'default'           => '',
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'stag_sanitize_textarea',
		),
	);

	$priority->reboot();

	$mods['footer'] = array(
		'footer-text' => array(
			'title'             => esc_html__( 'Footer Text', 'carbon' ),
			'type'              => 'text',
			'default'           => '',
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'stag_sanitize_text',
		),
		'hide-theme-credit' => array(
			'title'             => esc_html__( 'Hide Theme Credit', 'carbon' ),
			'type'              => 'checkbox',
			'default'           => false,
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
			'sanitize_callback' => 'wp_validate_boolean',
		),
	);

	$mods = apply_filters( 'stag_theme_mods', $mods );

	/** Return all keys within all sections (for transport, etc) */
	if ( $args['keys_only'] ) {
		$transport = array();

		foreach ( $mods as $section => $settings ) {
			foreach ( $settings as $key => $setting ) {
				if ( isset( $setting['transport'] ) ) {
					$transport[ $key ] = $setting['transport'];
				} else {
					$transport[ $key ] = '';
				}
			}
		}

		return $transport;
	}

	return $mods;
}

if ( class_exists( 'WP_Customize_Image_Control' ) && ! class_exists( 'Carbon_Customize_Image_Control' ) ) :
/**
 * Class Carbon_Customize_Image_Control
 *
 * Extend WP_Customize_Image_Control allowing access to uploads made within the same context.
 *
 * @since 1.0.0.
 */
class Carbon_Customize_Image_Control extends WP_Customize_Image_Control {
	/**
	 * Override the stock tab_uploaded function.
	 *
	 * @since  1.0.0.
	 *
	 * @return void
	 */
	public function tab_uploaded() {
		$images = get_posts( array(
			'post_type'  => 'attachment',
			'meta_key'   => '_wp_attachment_context',
			'meta_value' => $this->context,
			'orderby'    => 'none',
			'nopaging'   => true,
		) );

		?><div class="uploaded-target"></div><?php

		if ( empty( $images ) ) {
			return;
		}

		foreach ( (array) $images as $image ) {
			$thumbnail_url = wp_get_attachment_image_src( $image->ID, 'medium' );
			$this->print_tab_image( esc_url_raw( $image->guid ), esc_url_raw( $thumbnail_url[0] ) );
		}
	}
}
endif;

/**
 * Layout Picker Control
 *
 * Attach the custom layout picker control to the `customize_register` action
 * so the WP_Customize_Control class is initiated.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 * @return void
 */
function carbon_customizer_layout_control( $wp_customize ) {
	class Carbon_Customizer_Layout_Control extends WP_Customize_Control {
		public $type = 'layout';

		public function render_content() {

			$img_dir = get_template_directory_uri() . '/assets/img/';
			?>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<ul>
			<?php

			foreach ( $this->choices as $key => $value ) {
				?>
				<li class="customizer-control-row">
					<input type="radio" value="<?php echo esc_attr( $key ) ?>" name="<?php echo esc_attr( $this->id ); ?>" <?php echo esc_attr( $this->link() ); ?> <?php if ( $this->value() === $key ) echo 'checked="checked"'; ?>>
					<label for="<?php echo esc_attr( $this->id );  ?>[key]"><?php echo esc_html( $value ); ?></label>
				</li>
				<?php
			}

			?> </ul> <?php
		}
	}
}
add_action( 'customize_register', 'carbon_customizer_layout_control', 1, 1 );

function carbon_customizer_layout_css() {
	?>
	<style type="text/css">
		.customizer-control-row {
			position: relative;
			display: inline-block;
			vertical-align: top;
			width: 127px;
			height: 100px;
			overflow: hidden;
			margin: 0 0 7px 0;
			font: 0/0 a;
		}
		.customizer-control-row:nth-child(2n+2) {
			margin-left: 4px;
		}

		.customizer-control-row:nth-child(1) label { background-position: 0 0; }
		.customizer-control-row:nth-child(2) label { background-position: -273px 0; }
		.customizer-control-row:nth-child(3) label { background-position: -136px 0; }
		.customizer-control-row:nth-child(4) label { background-position: -409px 0; }

		.customizer-control-row input {
			position: absolute;
			width: 100%;
			height: 100%;
			opacity: 0;
		}
		.customizer-control-row input,
		.customizer-control-row label {
			width: 100%;
		}
		.customizer-control-row label {
			height: 100px;
			background: url("<?php echo get_template_directory_uri(); ?>/assets/img/normal.png") no-repeat;
			background-size: 536px 100px;
			display: block;
			box-sizing: border-box;
		}

		.customizer-control-row input[type="radio"]:checked + label {
			background-image: url("<?php echo get_template_directory_uri(); ?>/assets/img/hover.png");
		}

		#stag-loading {
			background: #333;
			padding: 10px 0;
			/*border-radius: 5px;*/
			color: white;
			width: 40px;
			position: absolute;
			top: 30px;
			right: 30px;
			text-align: center;
		}

		#customize-control-nav-layout label {
			display: inline-block;
		}

		.accordion-section .customize-control-image .preview-thumbnail img {
			width: auto;
			height: auto;
		}
	</style>
	<?php
}
add_action( 'customize_controls_print_scripts', 'carbon_customizer_layout_css' );

if ( ! function_exists( 'stag_sanitize_textarea' ) ) :
function stag_sanitize_textarea( $value ) {
	global $allowedtags;

	$newtags = array(
		'h1' => array(),
		'h2' => array(),
		'h3' => array(),
		'h4' => array(),
		'h5' => array(),
		'h6' => array(),
	);

	$updated_tags = array_merge( $allowedtags, $newtags );

	return wp_kses( $value, $updated_tags );
}
endif;

if ( ! function_exists( 'stag_sanitize_radio' ) ) :
function stag_sanitize_radio( $input, $setting ) {
	global $wp_customize;

	$control = $wp_customize->get_control( $setting->id );

	if ( array_key_exists( $input, $control->choices ) ) {
		return $input;
	} else {
		return $setting->default;
	}
}
endif;
