<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package Carbon
 */

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 *
 * @param array $args Configuration arguments.
 * @return array
 */
function carbon_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'carbon_page_menu_args' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function carbon_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	$nav_layout = stag_theme_mod( 'theme_options', 'nav-layout' );

	if ( isset( $nav_layout ) ) {
		if ( ( is_page() && ! has_post_thumbnail() ) || is_attachment() ) {
			$classes[] = 'nav-stripped nav-simple';
		} else if ( is_single() && ! has_post_thumbnail() ) {
			$classes[] = 'nav-stripped nav-simple';
		} else if ( is_search() && in_array( 'search-no-results', $classes ) ) {
			$classes[] = 'nav-stripped nav-simple';
		} else {
			$classes[] = 'nav-' . $nav_layout;
		}
	}

	if ( ! is_singular() ) {
		$classes[] = 'layout-' . stag_theme_mod( 'theme_options', 'layout' );
	}

	if ( stag_theme_mod( 'theme_options', 'hide-sidebar' ) ) {
		$classes[] = 'hide-sidebar';
	}

	if (  ( is_single() || is_page() ) && stag_theme_mod( 'theme_options', 'hide-sidebar-on-posts' ) ) {
		$classes[] = 'hide-sidebar';
	}

	$post_titles = stag_theme_mod( 'theme_options', 'post-titles-visibility' );
	if ( '' != $post_titles ) {
		$classes[] = 'overlay-' . $post_titles;
	}

	return $classes;
}
add_filter( 'body_class', 'carbon_body_classes' );

/**
 * Sets the authordata global when viewing an author archive.
 *
 * This provides backwards compatibility with
 * http://core.trac.wordpress.org/changeset/25574
 *
 * It removes the need to call the_post() and rewind_posts() in an author
 * template to print information about the author.
 *
 * @global WP_Query $wp_query WordPress Query object.
 * @return void
 */
function carbon_setup_author() {
	global $wp_query;

	if ( $wp_query->is_author() && isset( $wp_query->post ) ) {
		$GLOBALS['authordata'] = get_userdata( $wp_query->post->post_author );
	}
}
add_action( 'wp', 'carbon_setup_author' );
