<?php
/**
 * @package Stag_Customizer
 * @subpackage Starter
 */

if ( ! function_exists( 'stag_css_add_rules' ) ) :
/**
 * Process user options to generate CSS needed to implement the choices.
 *
 * @since 1.0.0.
 *
 * @return void
 */
function stag_css_add_rules() {
	$accent            = stag_theme_mod( 'colors', 'accent' );

	$font_header       = stag_theme_mod( 'fonts', 'font-header' );
	$font_header_stack = stag_get_font_stack( $font_header );

	$font_body         = stag_theme_mod( 'fonts', 'font-body' );
	$font_body_stack   = stag_get_font_stack( $font_body );

	if ( '' !== $font_header_stack && 'sans-serif' != $font_header ) {
		stag_get_css()->add( array(
			'selectors' => array(
				'h1',
				'h2',
				'h3',
				'h4',
				'h5',
				'h6',
			),
			'declarations' => array(
				'font-family' => $font_header_stack,
				'letter-spacing' => 'normal',
			)
		) );
	}

	if ( '' !== $font_body_stack && 'serif' != $font_body ) {
		stag_get_css()->add( array(
			'selectors'    => array(
				'body',
				'.font-body',
				'.entry-subtitle',
			),
			'declarations' => array(
				'font-family' => $font_body_stack,
			)
		) );
	}

	if ( '' !== $accent ) {
		stag_get_css()->add( array(
			'selectors' => array(
				'a',
				'.widget-area a:hover',
			),
			'declarations' => array(
				'color' => $accent,
			)
		) );

		stag_get_css()->add( array(
			'selectors' => array(
				'button',
				'.button',
				'div[id*="contact-form-"] h3',
				'.twitter-follow-button',
				'input[type="button"]',
				'input[type="reset"]',
				'input[type="submit"]',
			),
			'declarations' => array(
				'background-color' => $accent,
			)
		) );
	}

	$overlay_nav_color = stag_theme_mod( 'colors', 'overlay-nav-color' );
	if ( '' !== $overlay_nav_color ) {
		stag_get_css()->add( array(
			'selectors' => array(
				'.main-navigation a',
				'.jetpack-social-navigation a',
			),
			'declarations' => array(
				'color' => $overlay_nav_color,
			)
		) );
	}
	$overlay_nav_hover_color = stag_theme_mod( 'colors', 'overlay-nav-hover-color' );
	if ( '' !== $overlay_nav_hover_color && $overlay_nav_hover_color !== $overlay_nav_color ) {
		stag_get_css()->add( array(
			'selectors' => array(
				'.main-navigation a:hover',
				'.jetpack-social-navigation a:hover',
			),
			'declarations' => array(
				'color' => $overlay_nav_hover_color,
			)
		) );
	}

	$header_text_color = get_header_textcolor();
	if ( '' !== $header_text_color ) {
		stag_get_css()->add( array(
			'selectors' => array(
				'.custom-header',
			),
			'declarations' => array(
				'color' => '#' . $header_text_color,
			)
		) );
	}
}
endif;

add_action( 'stag_css', 'stag_css_add_rules' );
